@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 2006-2013 Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright (c) 2006-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -79,8 +79,6 @@
 
 # ifdef USE_IPHONE
   UIDeviceOrientation orientation, new_orientation;
-  double tap_time;
-  CGPoint tap_point;
   BOOL screenLocked;
 
   CGSize initial_bounds;
