@@ -1,5 +1,5 @@
 /* windows.c --- turning the screen black; dealing with visuals, virtual roots.
- * xscreensaver, Copyright (c) 1991-2011 Jamie Zawinski <jwz@jwz.org>
+ * xscreensaver, Copyright (c) 1991-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -396,10 +396,10 @@ ensure_no_screensaver_running (Display *dpy, Screen *screen)
 	  && type != None)
 	{
 	  unsigned char *id;
-	  if (!XGetWindowProperty (dpy, kids[i], XA_SCREENSAVER_ID, 0, 512,
+	  if (XGetWindowProperty (dpy, kids[i], XA_SCREENSAVER_ID, 0, 512,
 				   False, XA_STRING, &type, &format, &nitems,
 				   &bytesafter, &id)
-	      == Success
+	      != Success
 	      || type == None)
 	    id = (unsigned char *) "???";
 
@@ -1453,8 +1453,8 @@ resize_screensaver_window (saver_info *si)
             int x, y;
             unsigned int mask;
             XQueryPointer (si->dpy, ssi->screensaver_window, &root, &child,
-                           &ssi->poll_mouse_last_root_x,
-                           &ssi->poll_mouse_last_root_y,
+                           &ssi->last_poll_mouse.root_x,
+                           &ssi->last_poll_mouse.root_y,
                            &x, &y, &mask);
           }
         }
