@@ -56,7 +56,8 @@ fps_init (Display *dpy, Window window)
   st->x = 10;
   st->y = 10;
   if (get_boolean_resource (dpy, "fpsTop", "FPSTop"))
-    st->y = - (st->font->ascent + st->font->descent + 10);
+    /* don't leave a blank line in GL top-fps. */
+    st->y = - (/*st->font->ascent +*/ st->font->descent + 10);
 
   strcpy (st->string, "FPS: ... ");
 
@@ -152,7 +153,7 @@ fps_compute (fps_state *st, unsigned long polys, double depth)
 
       if (depth >= 0.0)
         {
-          int L = strlen (st->string);
+          unsigned long L = strlen (st->string);
           char *s = st->string + L;
           strcat (s, "\nDepth: ");
           sprintf (s + strlen(s), "%.1f", depth);
@@ -198,7 +199,7 @@ string_width (XFontStruct *f, const char *c, int *height_ret)
 }
 
 
-/* This function is used only in Xlib mode.  For GL mode, see glx/fps-glx.c.
+/* This function is used only in Xlib mode.  For GL mode, see glx/fps-gl.c.
  */
 void
 fps_draw (fps_state *st)
@@ -241,7 +242,7 @@ fps_draw (fps_state *st)
       s = strchr (string, '\n');
       if (! s) s = string + strlen(string);
       XDrawString (st->dpy, st->window, st->draw_gc,
-                   x, y, string, s - string);
+                   x, y, string, (int) (s - string));
       string = s;
       string++;
       lines--;
