@@ -1,4 +1,4 @@
-/* gears, Copyright (c) 2007 Jamie Zawinski <jwz@jwz.org>
+/* gears, Copyright (c) 2007-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -102,48 +102,6 @@ reshape_gears (ModeInfo *mi, int width, int height)
 }
 
 
-ENTRYPOINT Bool
-gears_handle_event (ModeInfo *mi, XEvent *event)
-{
-  gears_configuration *bp = &bps[MI_SCREEN(mi)];
-
-  if (event->xany.type == ButtonPress &&
-      event->xbutton.button == Button1)
-    {
-      bp->button_down_p = True;
-      gltrackball_start (bp->trackball,
-                         event->xbutton.x, event->xbutton.y,
-                         MI_WIDTH (mi), MI_HEIGHT (mi));
-      return True;
-    }
-  else if (event->xany.type == ButtonRelease &&
-           event->xbutton.button == Button1)
-    {
-      bp->button_down_p = False;
-      return True;
-    }
-  else if (event->xany.type == ButtonPress &&
-           (event->xbutton.button == Button4 ||
-            event->xbutton.button == Button5))
-    {
-      gltrackball_mousewheel (bp->trackball, event->xbutton.button, 10,
-                              !!event->xbutton.state);
-      return True;
-    }
-  else if (event->xany.type == MotionNotify &&
-           bp->button_down_p)
-    {
-      gltrackball_track (bp->trackball,
-                         event->xmotion.x, event->xmotion.y,
-                         MI_WIDTH (mi), MI_HEIGHT (mi));
-      return True;
-    }
-
-  return False;
-}
-
-
-
 static void
 free_gear (gear *g)
 {
@@ -690,16 +648,20 @@ planetary_gears (ModeInfo *mi)
   g4->y = 0;
   g4->th = -g3->th;
 
+  /* rotate central gear 1/2 tooth-size if odd number of teeth */
+  if (g4->nteeth & 1)
+    g4->th -= (180.0 / g4->nteeth);
+
   g0->inverted_p  = True;
   g0->x           = 0;
   g0->y           = 0;
-  g0->nteeth      = g4->nteeth * 3;
-  g0->r           = g4->r * 3.05;
+  g0->nteeth      = g1->nteeth * 3;
+  g0->r           = g1->r * 3.05;
   g0->inner_r     = g0->r * 0.8;
   g0->inner_r2    = 0;
   g0->inner_r3    = 0;
-  g0->th          = -(g4->th - (180 / g0->nteeth));
-  g0->ratio       = g4->ratio / 3;
+  g0->th          = g1->th + (180 / g0->nteeth);
+  g0->ratio       = g1->ratio / 3;
 
   g0->tooth_slope = 0;
   g0->nubs        = 3;
@@ -733,8 +695,6 @@ init_gears (ModeInfo *mi)
       fprintf(stderr, "%s: out of memory\n", progname);
       exit(1);
     }
-
-    bp = &bps[MI_SCREEN(mi)];
   }
 
   bp = &bps[MI_SCREEN(mi)];
@@ -761,20 +721,30 @@ init_gears (ModeInfo *mi)
       glLightfv(GL_LIGHT0, GL_SPECULAR, spc);
     }
 
-  {
-    double spin_speed   = 0.5;
-    double wander_speed = 0.01;
-    double spin_accel   = 0.25;
+  if (! bp->rot)
+    {
+      double spin_speed   = 0.5;
+      double wander_speed = 0.01;
+      double spin_accel   = 0.25;
 
-    bp->rot = make_rotator (do_spin ? spin_speed : 0,
-                            do_spin ? spin_speed : 0,
-                            do_spin ? spin_speed : 0,
-                            spin_accel,
-                            do_wander ? wander_speed : 0,
-                            True
-                            );
-    bp->trackball = gltrackball_init ();
-  }
+      bp->rot = make_rotator (do_spin ? spin_speed : 0,
+                              do_spin ? spin_speed : 0,
+                              do_spin ? spin_speed : 0,
+                              spin_accel,
+                              do_wander ? wander_speed : 0,
+                              True
+                              );
+      bp->trackball = gltrackball_init (True);
+    }
+
+  if (bp->gears)
+    {
+      for (i = 0; i < bp->ngears; i++)
+        free_gear (bp->gears[i]);
+      free (bp->gears);
+      bp->gears = 0;
+      bp->ngears = 0;
+    }
 
   if (!(random() % 8))
     {
@@ -784,10 +754,11 @@ init_gears (ModeInfo *mi)
     {
       gear *g = 0;
       int total_gears = MI_COUNT (mi);
-      int i;
+
+      bp->planetary_p = False;
+
       if (total_gears <= 0)
         total_gears = 3 + abs (BELLRAND (8) - 4);  /* 3 - 7, mostly 3. */
-
       bp->gears = (gear **) calloc (total_gears+2, sizeof(**bp->gears));
       bp->ngears = 0;
 
@@ -934,6 +905,24 @@ draw_gears (ModeInfo *mi)
   glXSwapBuffers(dpy, window);
 }
 
+ENTRYPOINT Bool
+gears_handle_event (ModeInfo *mi, XEvent *event)
+{
+  gears_configuration *bp = &bps[MI_SCREEN(mi)];
+
+  if (gltrackball_event_handler (event, bp->trackball,
+                                 MI_WIDTH (mi), MI_HEIGHT (mi),
+                                 &bp->button_down_p))
+    return True;
+  else if (screenhack_event_helper (MI_DISPLAY(mi), MI_WINDOW(mi), event))
+    {
+      init_gears (mi);
+      return True;
+    }
+
+  return False;
+}
+
 XSCREENSAVER_MODULE ("Gears", gears)
 
 #endif /* USE_GL */
