@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 1997-2012 Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright (c) 1997-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -486,7 +486,7 @@ draw_piece (jigsaw_configuration *jc, puzzle_piece *p,
 
   { GLfloat ss = 1.0 / resolution; glScalef (ss, ss, ss); }
 
-# ifndef HAVE_JWZGLES
+# ifndef HAVE_JWZGLES /* #### glPolygonMode other than GL_FILL unimplemented */
   glPolygonMode (GL_FRONT_AND_BACK, wire ? GL_LINE : GL_FILL);
 # endif
 
@@ -1345,53 +1345,16 @@ jigsaw_handle_event (ModeInfo *mi, XEvent *event)
 {
   jigsaw_configuration *jc = &sps[MI_SCREEN(mi)];
 
-  if (event->xany.type == ButtonPress &&
-      event->xbutton.button == Button1)
+  if (gltrackball_event_handler (event, jc->trackball,
+                                 MI_WIDTH (mi), MI_HEIGHT (mi),
+                                 &jc->button_down_p))
+    return True;
+  else if (screenhack_event_helper (MI_DISPLAY(mi), MI_WINDOW(mi), event))
     {
-      jc->button_down_p = True;
-      gltrackball_start (jc->trackball,
-                         event->xbutton.x, event->xbutton.y,
-                         MI_WIDTH (mi), MI_HEIGHT (mi));
+      begin_scatter (mi, False);
+      jc->state = PUZZLE_SCATTER;
       return True;
     }
-  else if (event->xany.type == ButtonRelease &&
-           event->xbutton.button == Button1)
-    {
-      jc->button_down_p = False;
-      return True;
-    }
-  else if (event->xany.type == ButtonPress &&
-           (event->xbutton.button == Button4 ||
-            event->xbutton.button == Button5 ||
-            event->xbutton.button == Button6 ||
-            event->xbutton.button == Button7))
-    {
-      gltrackball_mousewheel (jc->trackball, event->xbutton.button, 10,
-                              !!event->xbutton.state);
-      return True;
-    }
-  else if (event->xany.type == MotionNotify &&
-           jc->button_down_p)
-    {
-      gltrackball_track (jc->trackball,
-                         event->xmotion.x, event->xmotion.y,
-                         MI_WIDTH (mi), MI_HEIGHT (mi));
-      return True;
-    }
-  else if (event->xany.type == KeyPress)
-    {
-      KeySym keysym;
-      char c = 0;
-      XLookupString (&event->xkey, &c, 1, &keysym, 0);
-
-      if (c == ' ' || c == '\t' || c == '\r' || c == '\n')
-        {
-          begin_scatter (mi, False);
-          jc->state = PUZZLE_SCATTER;
-          return True;
-        }
-    }
-
 
   return False;
 }
@@ -1429,7 +1392,7 @@ init_jigsaw (ModeInfo *mi)
       glLightfv(GL_LIGHT0, GL_SPECULAR, spc);
     }
 
-  jc->trackball = gltrackball_init ();
+  jc->trackball = gltrackball_init (False);
   jc->rot = make_rotator (0, 0, 0, 0, speed * 0.002, True);
   jc->texfont = load_texture_font (MI_DISPLAY(mi), "font");
 
