@@ -1,4 +1,4 @@
-/* molecule, Copyright (c) 2001-2006 Jamie Zawinski <jwz@jwz.org>
+/* molecule, Copyright (c) 2001-2014 Jamie Zawinski <jwz@jwz.org>
  * Draws molecules, based on coordinates from PDB (Protein Data Base) files.
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -24,10 +24,12 @@
    http://www.wwpdb.org/docs.html
  */
 
+#define ATOM_FONT "-*-helvetica-medium-r-normal-*-240-*"
+
 #define DEFAULTS	"*delay:	10000         \n" \
 			"*showFPS:      False         \n" \
 			"*wireframe:    False         \n" \
-			"*atomFont:   -*-helvetica-medium-r-normal-*-180-*\n" \
+			"*atomFont:   " ATOM_FONT "\n" \
 			"*atomFont2:  -*-helvetica-bold-r-normal-*-80-*\n" \
 			"*titleFont:  -*-helvetica-medium-r-normal-*-180-*\n" \
 			"*noLabelThreshold:    30     \n" \
@@ -87,11 +89,16 @@
                     ISO C89 compilers are required to support" when includng
                     the following data file... */
 # endif
-const char * const builtin_pdb_data[] = {
+static const char * const builtin_pdb_data[] = {
 # include "molecules.h"
 };
 
 
+#ifndef USE_IPHONE
+# define LOAD_FILES
+#endif
+
+
 typedef struct {
   const char *name;
   GLfloat size, size2;
@@ -160,8 +167,8 @@ typedef struct {
   GLuint molecule_dlist;
   GLuint shell_dlist;
 
-  XFontStruct *xfont1, *xfont2, *xfont3;
-  GLuint font1_dlist, font2_dlist, font3_dlist;
+  texture_font_data *font1_data, *font2_data, *font3_data;
+
   int polygon_count;
 
   time_t draw_time;
@@ -258,9 +265,9 @@ static void
 load_fonts (ModeInfo *mi)
 {
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
-  load_font (mi->dpy, "atomFont",  &mc->xfont1, &mc->font1_dlist);
-  load_font (mi->dpy, "atomFont2", &mc->xfont2, &mc->font2_dlist);
-  load_font (mi->dpy, "titleFont", &mc->xfont3, &mc->font3_dlist);
+  mc->font1_data = load_texture_font (mi->dpy, "atomFont");
+  mc->font2_data = load_texture_font (mi->dpy, "atomFont2");
+  mc->font3_data = load_texture_font (mi->dpy, "titleFont");
 }
 
 
@@ -470,7 +477,6 @@ draw_bounding_box (ModeInfo *mi)
   glVertex3f(x2, y2, z2); glVertex3f(x2, y2, z1);
   glEnd();
 
-  glPushAttrib (GL_LIGHTING);
   glDisable (GL_LIGHTING);
 
   glColor3f (c2[0], c2[1], c2[2]);
@@ -483,7 +489,8 @@ draw_bounding_box (ModeInfo *mi)
   glVertex3f(0,  0,  z1); glVertex3f(0,  0,  z2); 
   glEnd();
 
-  glPopAttrib();
+  if (!wire)
+    glEnable (GL_LIGHTING);
 }
 
 
@@ -866,6 +873,7 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
 }
 
 
+#ifdef LOAD_FILES
 static int
 parse_pdb_file (molecule *m, const char *name)
 {
@@ -912,6 +920,7 @@ parse_pdb_file (molecule *m, const char *name)
 
   return 0;
 }
+#endif /* LOAD_FILES */
 
 
 typedef struct { char *atom; int count; } atom_and_count;
@@ -1029,16 +1038,17 @@ static void
 load_molecules (ModeInfo *mi)
 {
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
-  int wire = MI_IS_WIREFRAME(mi);
   int i;
 
   mc->nmolecules = 0;
+# ifdef LOAD_FILES
   if (molecule_str && *molecule_str && 
       strcmp(molecule_str, "(default)"))	/* try external PDB files */
     {
       /* The -molecule option can point to a .pdb file, or to
          a directory of them.
       */
+      int wire = MI_IS_WIREFRAME(mi);
       struct stat st;
       int nfiles = 0;
       int list_size = 0;
@@ -1142,6 +1152,7 @@ load_molecules (ModeInfo *mi)
       files = 0;
       mc->nmolecules = molecule_ctr;
     }
+# endif /* LOAD_FILES */
 
   if (mc->nmolecules == 0)	/* do the builtins if no files */
     {
@@ -1207,7 +1218,7 @@ startup_blurb (ModeInfo *mi)
 {
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
   const char *s = "Constructing molecules...";
-  print_gl_string (mi->dpy, mc->xfont3, mc->font3_dlist,
+  print_gl_string (mi->dpy, mc->font3_data,
                    mi->xgwa.width, mi->xgwa.height,
                    10, mi->xgwa.height - 10,
                    s, False);
@@ -1220,51 +1231,15 @@ molecule_handle_event (ModeInfo *mi, XEvent *event)
 {
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
 
-  if (event->xany.type == ButtonPress &&
-      event->xbutton.button == Button1)
+  if (gltrackball_event_handler (event, mc->trackball,
+                                 MI_WIDTH (mi), MI_HEIGHT (mi),
+                                 &mc->button_down_p))
+    return True;
+  else if (screenhack_event_helper (MI_DISPLAY(mi), MI_WINDOW(mi), event))
     {
-      mc->button_down_p = True;
-      gltrackball_start (mc->trackball,
-                         event->xbutton.x, event->xbutton.y,
-                         MI_WIDTH (mi), MI_HEIGHT (mi));
-      return True;
-    }
-  else if (event->xany.type == ButtonRelease &&
-           event->xbutton.button == Button1)
-    {
-      mc->button_down_p = False;
-      return True;
-    }
-  else if (event->xany.type == ButtonPress &&
-           (event->xbutton.button == Button4 ||
-            event->xbutton.button == Button5 ||
-            event->xbutton.button == Button6 ||
-            event->xbutton.button == Button7))
-    {
-      gltrackball_mousewheel (mc->trackball, event->xbutton.button, 10,
-                              !!event->xbutton.state);
-      return True;
-    }
-  else if (event->xany.type == KeyPress)
-    {
-      KeySym keysym;
-      char c = 0;
-      XLookupString (&event->xkey, &c, 1, &keysym, 0);
-
-      if (c == ' ' || c == '\t' || c == '\r' || c == '\n')
-        {
-          GLfloat speed = 4.0;
-          mc->mode = 1;
-          mc->mode_tick = 10 * speed;
-          return True;
-        }
-    }
-  else if (event->xany.type == MotionNotify &&
-           mc->button_down_p)
-    {
-      gltrackball_track (mc->trackball,
-                         event->xmotion.x, event->xmotion.y,
-                         MI_WIDTH (mi), MI_HEIGHT (mi));
+      GLfloat speed = 4.0;
+      mc->mode = 1;
+      mc->mode_tick = 10 * speed;
       return True;
     }
 
@@ -1328,7 +1303,7 @@ init_molecule (ModeInfo *mi)
                             spin_accel,
                             do_wander ? wander_speed : 0,
                             (spinx && spiny && spinz));
-    mc->trackball = gltrackball_init ();
+    mc->trackball = gltrackball_init (True);
   }
 
   orig_do_labels = do_labels;
@@ -1365,9 +1340,7 @@ draw_labels (ModeInfo *mi)
   molecule_configuration *mc = &mcs[MI_SCREEN(mi)];
   int wire = MI_IS_WIREFRAME(mi);
   molecule *m = &mc->molecules[mc->which];
-  XFontStruct *xfont = (mc->scale_down ? mc->xfont2 : mc->xfont1);
-  GLuint font_dlist  = (mc->scale_down ? mc->font2_dlist : mc->font1_dlist);
-  int i, j;
+  int i;
 
   if (!do_labels)
     return;
@@ -1421,18 +1394,20 @@ draw_labels (ModeInfo *mi)
 
       glTranslatef (0, 0, (size * 1.1));           /* move toward camera */
 
-      glRasterPos3f (0, 0, 0);                     /* draw text here */
+      glRotatef (current_device_rotation(), 0, 0, 1);  /* right side up */
 
-      /* Before drawing the string, shift the origin to center
-         the text over the origin of the sphere. */
-      glBitmap (0, 0, 0, 0,
-                -string_width (xfont, a->label, 0) / 2,
-                -xfont->descent,
-                NULL);
-
-      for (j = 0; j < strlen(a->label); j++)
-
-        glCallList (font_dlist + (int)(a->label[j]));
+      {
+        int h;
+        int w = texture_string_width (mc->font1_data, a->label, &h);
+        GLfloat s = 1.0 / h;
+        GLfloat max = 18;   /* max point size to avoid pixellated text */
+        if (h > max) s *= max/h;
+        glScalef (s, s, 1);
+        glTranslatef (-w/2, h*2/3, 0);
+        print_gl_string (mi->dpy, mc->font1_data,
+                         0, 0, 0, 0,
+                         a->label, False);
+      }
 
       glPopMatrix();
     }
@@ -1627,7 +1602,7 @@ draw_molecule (ModeInfo *mi)
       if (do_titles && m->label && *m->label)
         {
           set_atom_color (mi, 0, True, 1);
-          print_gl_string (mi->dpy, mc->xfont3, mc->font3_dlist,
+          print_gl_string (mi->dpy, mc->font3_data,
                            mi->xgwa.width, mi->xgwa.height,
                            10, mi->xgwa.height - 10,
                            m->label, False);
