@@ -1,4 +1,4 @@
-/* texfonts, Copyright (c) 2005 Jamie Zawinski <jwz@jwz.org>
+/* texfonts, Copyright (c) 2005-2014 Jamie Zawinski <jwz@jwz.org>
  * Loads X11 fonts into textures for use with OpenGL.
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -20,13 +20,15 @@ typedef struct texture_font_data texture_font_data;
 */
 extern texture_font_data *load_texture_font (Display *, char *res);
 
-/* Width of the string in pixels.
+/* Bounding box of the multi-line string, in pixels.
  */
 extern int texture_string_width (texture_font_data *, const char *,
-                                 int *line_height_ret);
+                                 int *height_ret);
 
 /* Draws the string in the scene at the origin.
    Newlines and tab stops are honored.
+   Any numbers inside [] will be rendered as a subscript.
+   Assumes the font has been loaded as with load_texture_font().
  */
 extern void print_texture_string (texture_font_data *, const char *);
 
