@@ -1,5 +1,5 @@
 /* xlock-gl.c --- xscreensaver compatibility layer for xlockmore GL modules.
- * xscreensaver, Copyright (c) 1997-2008 Jamie Zawinski <jwz@jwz.org>
+ * xscreensaver, Copyright (c) 1997-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -18,10 +18,6 @@
 #include "xlockmoreI.h"
 #include "glxfonts.h"
 
-#include <GL/gl.h>
-#include <GL/glu.h>
-#include <GL/glx.h>
-
 #ifndef isupper
 # define isupper(c)  ((c) >= 'A' && (c) <= 'Z')
 #endif
@@ -60,6 +56,10 @@ init_GL(ModeInfo * mi)
   XVisualInfo vi_in, *vi_out;
   int out_count;
 
+# ifdef HAVE_JWZGLES
+  jwzgles_reset();
+# endif
+
   vi_in.screen = screen_number (screen);
   vi_in.visualid = XVisualIDFromVisual (visual);
   vi_out = XGetVisualInfo (dpy, VisualScreenMask|VisualIDMask,
@@ -144,7 +144,6 @@ init_GL(ModeInfo * mi)
   }
 }
 
-
 
 
 /* clear away any lingering error codes */
