@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 1992-2013 Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright (c) 1992-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -153,7 +153,7 @@ static XrmOptionDescRec default_options [] = {
 
 static char *default_defaults[] = {
   ".root:		false",
-  "*geometry:		600x480", /* this should be .geometry, but nooooo... */
+  "*geometry:		1280x720", /* this should be .geometry, but noooo... */
   "*mono:		false",
   "*installColormap:	false",
   "*doFPS:		false",
