@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 1992-2008 Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright (c) 1992-2014 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -440,6 +440,12 @@ slidescreen_reshape (Display *dpy, Window window, void *closure,
 static Bool
 slidescreen_event (Display *dpy, Window window, void *closure, XEvent *event)
 {
+  struct state *st = (struct state *) closure;
+  if (screenhack_event_helper (dpy, window, event))
+    {
+      st->start_time = 0;
+      return True;
+    }
   return False;
 }
 
@@ -469,6 +475,10 @@ static const char *slidescreen_defaults [] = {
   "*delay:			50000",
   "*delay2:			1000000",
   "*duration:			120",
+#ifdef USE_IPHONE
+  "*ignoreRotation:             True",
+  "*rotateImages:               True",
+#endif
   0
 };
 
