@@ -290,6 +290,12 @@ spotlight_reshape (Display *dpy, Window window, void *closure,
 static Bool
 spotlight_event (Display *dpy, Window window, void *closure, XEvent *event)
 {
+  struct state *st = (struct state *) closure;
+  if (screenhack_event_helper (dpy, window, event))
+    {
+      st->start_time = 0;
+      return True;
+    }
   return False;
 }
 
@@ -320,6 +326,10 @@ static const char *spotlight_defaults [] = {
   "*delay:			10000",
   "*duration:			120",
   "*radius:			125",
+#ifdef USE_IPHONE
+  "*ignoreRotation:             True",
+  "*rotateImages:               True",
+#endif
   0
 };
 
