@@ -489,6 +489,9 @@ static const char *whirlwindwarp_defaults [] = {
   "*points:	400",
   "*tails:	8",
   "*meters:	false",
+#ifdef USE_IPHONE
+  "*ignoreRotation: True",
+#endif
   0
 };
 
